@@ -21,6 +21,9 @@
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 ** See the GNU General Public License for more details.
 */
+#ifndef __ATOP__
+#define __ATOP__
+
 #define	EQ		0
 #define SECONDSINDAY	86400
 #define RAWNAMESZ	256
@@ -94,6 +97,9 @@ extern time_t		begintime, endtime, cursortime;	// epoch or time in day
 extern char		flaglist[];
 extern struct visualize vis;
 
+extern char		displaymode;
+extern char		barmono;
+
 extern int      	osrel;
 extern int		osvers;
 extern int      	ossub;
@@ -207,3 +213,12 @@ void		netatop_exithash(char);
 void		netatop_exitfind(unsigned long, struct tstat *, struct tstat *);
 void		set_oom_score_adj(void);
 int		run_in_guest(void);
+
+void		getusr1(int), getusr2(int);
+void		do_pacctdir(char *, char *);
+void		do_atopsarflags(char *, char *);
+
+int		netlink_open(void);
+int		netlink_recv(int, int);
+
+#endif
