@@ -529,6 +529,18 @@ calcdiff(struct tstat *devstat, const struct tstat *curstat,
 	devstat->cpu.blkdelay  =
 		subcount(curstat->cpu.blkdelay, prestat->cpu.blkdelay);
 
+	if (curstat->cpu.nvcsw >= prestat->cpu.nvcsw)
+		devstat->cpu.nvcsw  =
+			subcount(curstat->cpu.nvcsw, prestat->cpu.nvcsw);
+	else
+		devstat->cpu.nvcsw = curstat->cpu.nvcsw;
+
+	if (curstat->cpu.nivcsw >= prestat->cpu.nivcsw)
+		devstat->cpu.nivcsw =
+			subcount(curstat->cpu.nivcsw, prestat->cpu.nivcsw);
+	else
+		devstat->cpu.nivcsw = curstat->cpu.nivcsw;
+
 	devstat->dsk.rio    =
 		subcount(curstat->dsk.rio, prestat->dsk.rio);
 	devstat->dsk.rsz    =
@@ -1053,7 +1065,7 @@ deviatsyst(struct sstat *cur, struct sstat *pre, struct sstat *dev,
 		/*
 		** determine new j
 		*/
-		if (pre->dsk.dsk[j].name)	// existing matching entry
+		if (pre->dsk.dsk[j].name[0])	// existing matching entry
 			j++;
 		else
 			j = realj;		// empty entry: stick to old j
@@ -1122,7 +1134,7 @@ deviatsyst(struct sstat *cur, struct sstat *pre, struct sstat *dev,
 		/*
 		** determine new j
 		*/
-		if (pre->dsk.mdd[j].name)	// existing matching entry
+		if (pre->dsk.mdd[j].name[0])	// existing matching entry
 			j++;
 		else
 			j = realj;		// empty entry: stick to old j
@@ -1191,7 +1203,7 @@ deviatsyst(struct sstat *cur, struct sstat *pre, struct sstat *dev,
 		/*
 		** determine new j
 		*/
-		if (pre->dsk.lvm[j].name)	// existing matching entry
+		if (pre->dsk.lvm[j].name[0])	// existing matching entry
 			j++;
 		else
 			j = realj;		// empty entry: stick to old j
