@@ -23,6 +23,9 @@
 ** See the GNU General Public License for more details.
 */
 
+#ifndef __PHOTOPROC__
+#define __PHOTOPROC__
+
 #define	PNAMLEN		15
 #define	CMDLEN		255
 #define	CGRLEN		64
@@ -83,7 +86,9 @@ struct tstat {
 		char	wchan[16];	/* wait channel string    	*/
 		count_t	rundelay;	/* schedstat rundelay (nanosec)	*/
 		count_t	blkdelay;	/* blkio delay (ticks)		*/
-		count_t	cfuture[3];	/* reserved for future use	*/
+		count_t nvcsw;		/* voluntary cxt switch counts  */
+		count_t nivcsw;		/* involuntary csw counts       */
+		count_t	cfuture[1];	/* reserved for future use	*/
 	} cpu;
 
 	/* DISK STATISTICS						*/
@@ -198,3 +203,5 @@ void		deviattask(struct tstat *, unsigned long,
 
 unsigned long	photoproc(struct tstat *, int);
 unsigned long	counttasks(void);
+
+#endif
