@@ -21,10 +21,19 @@
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 ** See the GNU General Public License for more details.
 */
+#ifndef __SHOWGENERIC__
+#define __SHOWGENERIC__
+
 #define USERSTUB	9999999
 #define MAXUSERSEL	64
 #define MAXPID		32
 
+// minimum screen dimensions
+//
+#define MINLINES        24
+#define MINCOLUMNS      60
+
+
 struct syscap {
 	int	nrcpu;
 	count_t	availcpu;
@@ -71,12 +80,82 @@ struct sselection {
 };
 
 /*
-** color names
+** color definitions
 */
-#define	COLORINFO	2
-#define	COLORALMOST	3
-#define	COLORCRIT	4
-#define	COLORTHR	5
+#define COLOR_MYORANGE  20
+#define COLOR_MYGREEN   21
+#define COLOR_MYGREY    22
+
+#define COLOR_MYBROWN1  24
+#define COLOR_MYBROWN2  25
+
+#define COLOR_MYBLUE0   26
+#define COLOR_MYBLUE1   27
+#define COLOR_MYBLUE2   28
+#define COLOR_MYBLUE3   29
+#define COLOR_MYBLUE4   30
+#define COLOR_MYBLUE5   31
+
+#define COLOR_MYGREEN0  35
+#define COLOR_MYGREEN1  36
+#define COLOR_MYGREEN2  37
+
+/*
+** color pair definitions
+*/
+#define FGCOLORBORDER   1
+#define	FGCOLORINFO	2
+#define	FGCOLORALMOST	3
+#define	FGCOLORCRIT	4
+#define	FGCOLORTHR	5
+
+#define WHITE_GREEN     10
+#define WHITE_ORANGE    11
+#define WHITE_RED       12
+#define WHITE_GREY      13
+#define WHITE_BLUE      14
+#define WHITE_MAGENTA   15
+
+#define WHITE_BROWN1    18
+#define WHITE_BROWN2    19
+
+#define WHITE_BLUE0     20
+#define WHITE_BLUE1     21
+#define WHITE_BLUE2     22
+#define WHITE_BLUE3     23
+#define WHITE_BLUE4     24
+#define WHITE_BLUE5     25
+
+#define WHITE_GREEN0    30
+#define WHITE_GREEN1    31
+#define WHITE_GREEN2    32
+
+/*
+** text and bar color selections
+*/
+#define COLOROKAY       WHITE_GREEN
+#define COLORWARN       WHITE_ORANGE
+#define COLORBAD        WHITE_RED
+
+#define COLORCPUSYS     WHITE_BLUE1
+#define COLORCPUUSR     WHITE_BLUE2
+#define COLORCPUIDLE    WHITE_BLUE3
+#define COLORCPUSTEAL   WHITE_BLUE4
+#define COLORCPUGUEST   WHITE_BLUE5
+
+#define COLORMEMFREE    WHITE_GREEN
+#define COLORMEMCACH    WHITE_ORANGE
+#define COLORMEMUSED    WHITE_GREY
+#define COLORMEMSHM     WHITE_BROWN1
+#define COLORMEMTMP     WHITE_BLUE
+#define COLORMEMSLAB    WHITE_MAGENTA
+#define COLORMEMBAR     WHITE_BLUE3
+
+#define COLORDSKREAD	WHITE_GREEN1
+#define COLORDSKWRITE	WHITE_GREEN2
+
+#define COLORNETRECV	WHITE_BROWN1
+#define COLORNETSEND	WHITE_BROWN2
 
 /*
 ** list with keystrokes/flags
@@ -139,6 +218,15 @@ struct sselection {
 #define	MHELP1		'?'
 #define	MHELP2		'h'
 
+#define MBARGRAPH	'B'
+#define	MBARLOWER	'L'
+#define	MBARMONO	'H'
+
+/*
+** extern pause indication
+*/
+extern int paused;
+
 /*
 ** general function prototypes
 */
@@ -161,3 +249,26 @@ int	prisyst(struct sstat  *, int, int, int, int, struct sselection *,
 int	priproc(struct tstat  **, int, int, int, int, int, char, char,
 	        struct syscap *, int, int);
 void	priphead(int, int, char *, char *, char, count_t);
+
+char	draw_samp(time_t, int, struct sstat *, char, char);
+
+void	do_username(char *, char *);
+void	do_procname(char *, char *);
+void	do_maxcpu(char *, char *);
+void	do_maxgpu(char *, char *);
+void	do_maxdisk(char *, char *);
+void	do_maxmdd(char *, char *);
+void	do_maxlvm(char *, char *);
+void	do_maxintf(char *, char *);
+void	do_maxifb(char *, char *);
+void	do_maxnfsm(char *, char *);
+void	do_maxcont(char *, char *);
+void	do_maxnuma(char *, char *);
+void	do_maxllc(char *, char *);
+void	do_colinfo(char *, char *);
+void	do_colalmost(char *, char *);
+void	do_colcrit(char *, char *);
+void	do_colthread(char *, char *);
+void	do_flags(char *, char *);
+
+#endif
