@@ -27,13 +27,10 @@
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ** --------------------------------------------------------------------------
-**
-** $Log: showlinux.h,v $
-** Initial revision
-**
-** Initial
-**
 */
+#ifndef __SHOWLINUX__
+#define __SHOWLINUX__
+
 #define MAXITEMS 80    /* The maximum number of items per line */
 
 /*
@@ -128,6 +125,34 @@ void showhdrline(proc_printpair* elemptr, int curlist, int totlist,
 void showprocline(proc_printpair* elemptr, struct tstat *curstat, 
                   double perc, int nsecs, int avgval);
 
+void do_cpucritperc(char *, char *);
+void do_gpucritperc(char *, char *);
+void do_memcritperc(char *, char *);
+void do_swpcritperc(char *, char *);
+void do_dskcritperc(char *, char *);
+void do_netcritperc(char *, char *);
+void do_swoutcritsec(char *, char *);
+void do_almostcrit(char *, char *);
+void do_ownsysprcline(char *, char *);
+void do_ownallcpuline(char *, char *);
+void do_ownindivcpuline(char *, char *);
+void do_owncplline(char *, char *);
+void do_owngpuline(char *, char *);
+void do_ownmemline(char *, char *);
+void do_ownswpline(char *, char *);
+void do_ownpagline(char *, char *);
+void do_ownmemnumaline(char *, char *);
+void do_owncpunumaline(char *, char *);
+void do_ownllcline(char *, char *);
+void do_owndskline(char *, char *);
+void do_ownnettransportline(char *, char *);
+void do_ownnetnetline(char *, char *);
+void do_ownnetinterfaceline(char *, char *);
+void do_owninfinibandline(char *, char *);
+void do_ownprocline(char *, char *);
+
+int  get_posval(char *, char *);
+
 extern sys_printdef *prcsyspdefs[];
 extern sys_printdef *cpusyspdefs[];
 extern sys_printdef *cpisyspdefs[];
@@ -432,6 +457,8 @@ extern proc_printdef procprt_SORTITEM;
 extern proc_printdef procprt_RUNDELAY;
 extern proc_printdef procprt_BLKDELAY;
 extern proc_printdef procprt_WCHAN;
+extern proc_printdef procprt_NVCSW;
+extern proc_printdef procprt_NIVCSW;
 extern proc_printdef procprt_CGROUP_PATH;
 extern proc_printdef procprt_CGRCPUWGT;
 extern proc_printdef procprt_CGRCPUMAX;
@@ -467,3 +494,5 @@ extern char *procprt_TCPSASZ_e(struct tstat *, int, int);
 extern char *procprt_TCPRASZ_e(struct tstat *, int, int);
 extern char *procprt_UDPSASZ_e(struct tstat *, int, int);
 extern char *procprt_UDPRASZ_e(struct tstat *, int, int);
+
+#endif
